package com.duben.roseplaylet.ui.activitys

import android.app.Dialog
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.duben.library.utils.GlideUtils
import com.duben.library.utils.nodoubleclick.AntiShake
import com.duben.roseplaylet.R
import com.duben.roseplaylet.common.Constant
import com.duben.roseplaylet.mvp.model.SeeWechat
import com.duben.roseplaylet.mvp.model.UserProfileData
import com.duben.roseplaylet.mvp.presenters.UserProfilePresenter
import com.duben.roseplaylet.mvp.views.UserProfileView
import com.duben.roseplaylet.ui.activitys.base.BaseActivity
import com.duben.roseplaylet.ui.adapter.UserProfileAlbumAdapter
import com.duben.roseplaylet.ui.widgets.DialogListener
import com.duben.roseplaylet.ui.widgets.ToBlackConfirmDialog
import com.duben.roseplaylet.ui.widgets.ToBlackDialog
import com.google.android.material.appbar.AppBarLayout
import kotlinx.android.synthetic.main.activity_user_profile.*
import kotlinx.android.synthetic.main.layout_user_profile_head.*
import kotlinx.android.synthetic.main.layout_user_profile_case.*
import kotlin.math.abs

/**
 * 描述：用户信息
 */
class UserProfileActivity : BaseActivity(), View.OnClickListener, UserProfileView {

    private lateinit var userProfileAlbumAdapter: UserProfileAlbumAdapter

    private var toUid = ""

    private var userIsMale = true

    private val userProfilePresenter by lazy { UserProfilePresenter() }

    private var userProfileData: UserProfileData? = null

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            toUid = it.getString(Constant.TO_UID, "")
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_user_profile

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        userProfilePresenter.attachView(this)

        initAppBar()
        initAlbumRcy()
        initListener()
    }

    override fun onResume() {
        super.onResume()
        userProfilePresenter.getMorePage(toUid)
    }

    private fun initView() {
        if (userIsMale) {
            // 男性
            view_male.visibility = View.VISIBLE
            tv_like_male.visibility = View.GONE
            tv_wechat.visibility = View.VISIBLE
            rl_top_female.visibility = View.GONE
            fl_head_male.visibility = View.VISIBLE
            tv_days.visibility = View.VISIBLE
            ll_impression.visibility = View.GONE
            tv_info_7.visibility = View.VISIBLE
        } else {
            // 女性
            view_male.visibility = View.GONE
            tv_like_male.visibility = View.VISIBLE
            tv_wechat.visibility = View.GONE
            rl_top_female.visibility = View.VISIBLE
            fl_head_male.visibility = View.GONE
            tv_days.visibility = View.GONE
            ll_impression.visibility = View.VISIBLE
            tv_info_5.visibility = View.VISIBLE
        }

    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_head_back -> finish()
            R.id.iv_head_share -> {

            }
            R.id.iv_head_more -> {
                showToBlackDialog()
            }
            R.id.iv_like, R.id.tv_like_male -> {

            }
            R.id.tv_chat -> {
                userProfileData?.let {
                    if (it.canChat) {
                        // TODO 直接聊
                        return
                    }
                    if (userIsMale) {
                        // 男性 非VIP TODO 弹解锁聊天弹框
                    } else {
                        // 女性
                        // TODO 弹出认证弹框
                    }
                }
            }
            R.id.tv_wechat -> {
                userProfilePresenter.seeWechat(toUid)
            }
        }
    }

    private fun initListener() {
        iv_head_back.setOnClickListener(this)
        iv_head_share.setOnClickListener(this)
        iv_head_more.setOnClickListener(this)
        tv_wechat.setOnClickListener(this)
        tv_chat.setOnClickListener(this)
        tv_like_male.setOnClickListener(this)
        iv_like.setOnClickListener(this)
    }

    override fun getMorePageSuc(data: UserProfileData) {
        this.userProfileData = data
        userIsMale = data.sex == 1
        initView()
        initData()
    }

    private fun initData() {
        userProfileData?.let {
            if (it.images?.isNotEmpty() == true) {
//                it.images
                userProfileAlbumAdapter.setNewInstance(arrayListOf())
            }

            if (userIsMale) {
                // 男性
                tv_days.text = "已注册" + it.days
                GlideUtils.loadImageView(this, it.headerUrl, iv_avatar_male)
                tv_label_distance.text = it.distance + "km"
                if (TextUtils.isEmpty(it.introduce)) {
                    tv_introduce_text.text = "小姐姐你好呀！"
                } else {
                    tv_introduce_text.text = it.introduce
                }
                // 喜欢女生特质
                if (TextUtils.isEmpty(it.findDescribe)) {
                    tv_info_7.text = it.findDescribe
                } else {
                    tv_info_7.text = "秘密"
                }

                if (it.online) {
                    tv_online_male.visibility = View.VISIBLE
                } else {
                    tv_online_male.visibility = View.GONE
                }

            } else {
                GlideUtils.loadImageView(this, it.headerUrl, iv_avatar_female)
                tv_label_distance.text = "距你" + it.distance + "km"
                if (TextUtils.isEmpty(it.introduce)) {
                    tv_introduce_text.text = "不知道写什么耶，哥哥帮我想想～"
                } else {
                    tv_introduce_text.text = it.introduce
                }
                tv_active.text = it.hallTime

                // 身型
                if (TextUtils.isEmpty(it.appearance)) {
                    tv_info_5.text = it.appearance
                } else {
                    tv_info_5.text = "秘密"
                }
            }

            tv_label_name.text = it.nickName
            tv_like_count.text = "" + it.likeCount + "人喜欢"

            tv_label_age.text = it.age
            if (!TextUtils.isEmpty(it.city)) {
                tv_label_address.visibility = View.VISIBLE
                tv_label_address.text = it.city
            }
            tv_info_1.visibility = View.GONE
            // 身高
            if (TextUtils.isEmpty(it.userHeight)) {
                tv_info_2.text = it.userHeight
            } else {
                tv_info_2.text = "秘密"
            }
            // 体重
            if (TextUtils.isEmpty(it.bodyWeight)) {
                tv_info_3.text = it.bodyWeight
            } else {
                tv_info_3.text = "秘密"
            }
            // 城市
            if (TextUtils.isEmpty(it.city)) {
                tv_info_4.text = it.city
            } else {
                tv_info_4.text = "秘密"
            }
            // 个性标签
            if (TextUtils.isEmpty(it.tagsCommon)) {
                tv_info_6.text = it.tagsCommon
            } else {
                tv_info_6.text = "秘密"
            }

            // 工作
            if (TextUtils.isEmpty(it.career)) {
                tv_info_8.text = it.career
            } else {
                tv_info_8.text = "秘密"
            }
        }

    }

    private fun initAlbumRcy() {
        rcy_album.layoutManager = LinearLayoutManager(context)
        val userProfileAlbumAdapter = UserProfileAlbumAdapter()
        userProfileAlbumAdapter.animationEnable = false
        rcy_album.adapter = userProfileAlbumAdapter
        val emptyView = LayoutInflater.from(this).inflate(R.layout.item_empty_data, null)
        userProfileAlbumAdapter.setEmptyView(emptyView)
        userProfileAlbumAdapter.setOnItemChildClickListener { adapter, view, position ->

        }
    }

    override fun getMorePageFail() {
    }

    override fun seeWechatSuc(data: SeeWechat) {
        if (data.canSee) {
            if (!data.hasWechat) {
                showToast(data.errMsg)
            } else {
                // TODO 直接看微信

            }

        } else {
            // TODO 弹VIP弹框

        }
    }

    override fun seeWechatFail() {
    }

    override fun unlockWechatSuc() {
    }

    override fun unlockWechatFail() {
    }

    override fun toWhiteSuc() {
        showToast("已将对方移出黑名单！")
        userProfileData?.black = 0
    }

    override fun toBlackSuc() {
        showToast("拉黑成功！")
        userProfileData?.black = 1
    }

    override fun onDestroy() {
        userProfilePresenter.detachView()
        super.onDestroy()
    }

    private fun showToBlackDialog() {
        userProfileData?.let {
            ToBlackDialog(this, it.black == 0, object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    super.onClick(dialog, v)
                    dialog?.dismiss()
                    when (v?.id) {
                        R.id.tv_to_black -> {
                            if (it.black == 1) {
                                userProfilePresenter.toWhite("" + it.uid)
                            } else {
                                Handler(Looper.getMainLooper()).postDelayed({

                                    ToBlackConfirmDialog(this@UserProfileActivity,
                                        object : DialogListener() {
                                            override fun onClick(dialog: Dialog?, v: View?) {
                                                super.onClick(dialog, v)
                                                dialog?.dismiss()
                                                if (v?.id == R.id.tv_confirm) {
                                                    userProfilePresenter.toBlack("" + it.uid)
                                                }
                                            }
                                        }).show()
                                }, 500)
                            }
                        }
                    }
                }
            }).show()
        }
    }

    private fun initAppBar() {
        appbar.addOnOffsetChangedListener(AppBarLayout.OnOffsetChangedListener { appBarLayout, verticalOffset ->
            //verticalOffset  当前偏移量 appBarLayout.getTotalScrollRange() 最大高度 便宜值
            val offset = abs(verticalOffset) //目的是将负数转换为绝对正数；

            if (userIsMale) {

            } else {
                // 标题栏的渐变
                toolbar.setBackgroundColor(
                    changeAlpha(
                        resources.getColor(R.color.color_232122),
                        abs(verticalOffset * 1.0f) / appBarLayout.totalScrollRange
                    )
                )
            }

            /**
             * 当前最大高度 在减去已偏移值 获取浮动 先显示在隐藏
             */
            if (offset < appBarLayout.totalScrollRange) {
                ll_head_center.alpha =
                    1 - (appBarLayout.totalScrollRange - offset * 1.0f) / (appBarLayout.totalScrollRange)
            } else if (offset > appBarLayout.totalScrollRange) {
                val floate =
                    (offset - appBarLayout.totalScrollRange) * 1.0f / (appBarLayout.totalScrollRange)
                ll_head_center.alpha = 1 - floate
            }
        })
    }

    /**
     * 根据百分比改变颜色透明度
     */
    fun changeAlpha(color: Int, fraction: Float): Int {
        val alpha = (Color.alpha(color) * fraction).toInt()
        return Color.argb(alpha, 35, 33, 34)
    }
}
